==> zio-aws-workspaces_3-5.17.147.1-sources.jar: zio/aws/workspaces/model/WorkspaceProperties.scala <==
package zio.aws.workspaces.model
import java.lang.Integer
import zio.aws.workspaces.model.primitives.{
  UserVolumeSizeGib,
  RootVolumeSizeGib,
  RunningModeAutoStopTimeoutInMinutes
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class WorkspaceProperties(
    runningMode: Option[zio.aws.workspaces.model.RunningMode] = None,
    runningModeAutoStopTimeoutInMinutes: Option[
      RunningModeAutoStopTimeoutInMinutes
    ] = None,
    rootVolumeSizeGib: Option[RootVolumeSizeGib] = None,
    userVolumeSizeGib: Option[UserVolumeSizeGib] = None,
    computeTypeName: Option[zio.aws.workspaces.model.Compute] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.WorkspaceProperties = {
    import WorkspaceProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
      .builder()
      .optionallyWith(runningMode.map(value => value.unwrap))(_.runningMode)
      .optionallyWith(
        runningModeAutoStopTimeoutInMinutes.map(value =>
          RunningModeAutoStopTimeoutInMinutes.unwrap(value): Integer
        )
      )(_.runningModeAutoStopTimeoutInMinutes)
      .optionallyWith(
        rootVolumeSizeGib.map(value => RootVolumeSizeGib.unwrap(value): Integer)
      )(_.rootVolumeSizeGib)
      .optionallyWith(
        userVolumeSizeGib.map(value => UserVolumeSizeGib.unwrap(value): Integer)
      )(_.userVolumeSizeGib)
      .optionallyWith(computeTypeName.map(value => value.unwrap))(
        _.computeTypeName
      )
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.WorkspaceProperties.ReadOnly =
    zio.aws.workspaces.model.WorkspaceProperties.wrap(buildAwsValue())
}
object WorkspaceProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.WorkspaceProperties =
      zio.aws.workspaces.model.WorkspaceProperties(
        runningMode.map(value => value),
        runningModeAutoStopTimeoutInMinutes.map(value => value),
        rootVolumeSizeGib.map(value => value),
        userVolumeSizeGib.map(value => value),
        computeTypeName.map(value => value)
      )
    def runningMode: Option[zio.aws.workspaces.model.RunningMode]
    def runningModeAutoStopTimeoutInMinutes
        : Option[RunningModeAutoStopTimeoutInMinutes]
    def rootVolumeSizeGib: Option[RootVolumeSizeGib]
    def userVolumeSizeGib: Option[UserVolumeSizeGib]
    def computeTypeName: Option[zio.aws.workspaces.model.Compute]
    def getRunningMode
        : ZIO[Any, AwsError, zio.aws.workspaces.model.RunningMode] =
      AwsError.unwrapOptionField("runningMode", runningMode)
    def getRunningModeAutoStopTimeoutInMinutes
        : ZIO[Any, AwsError, RunningModeAutoStopTimeoutInMinutes] =
      AwsError.unwrapOptionField(
        "runningModeAutoStopTimeoutInMinutes",
        runningModeAutoStopTimeoutInMinutes
      )
    def getRootVolumeSizeGib: ZIO[Any, AwsError, RootVolumeSizeGib] =
      AwsError.unwrapOptionField("rootVolumeSizeGib", rootVolumeSizeGib)
    def getUserVolumeSizeGib: ZIO[Any, AwsError, UserVolumeSizeGib] =
      AwsError.unwrapOptionField("userVolumeSizeGib", userVolumeSizeGib)
    def getComputeTypeName
        : ZIO[Any, AwsError, zio.aws.workspaces.model.Compute] =
      AwsError.unwrapOptionField("computeTypeName", computeTypeName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ) extends zio.aws.workspaces.model.WorkspaceProperties.ReadOnly {
    override val runningMode: Option[zio.aws.workspaces.model.RunningMode] =
      scala
        .Option(impl.runningMode())
        .map(value => zio.aws.workspaces.model.RunningMode.wrap(value))
    override val runningModeAutoStopTimeoutInMinutes
        : Option[RunningModeAutoStopTimeoutInMinutes] = scala
      .Option(impl.runningModeAutoStopTimeoutInMinutes())
      .map(value =>
        zio.aws.workspaces.model.primitives
          .RunningModeAutoStopTimeoutInMinutes(value)
      )
    override val rootVolumeSizeGib: Option[RootVolumeSizeGib] = scala
      .Option(impl.rootVolumeSizeGib())
      .map(value =>
        zio.aws.workspaces.model.primitives.RootVolumeSizeGib(value)
      )
    override val userVolumeSizeGib: Option[UserVolumeSizeGib] = scala
      .Option(impl.userVolumeSizeGib())
      .map(value =>
        zio.aws.workspaces.model.primitives.UserVolumeSizeGib(value)
      )
    override val computeTypeName: Option[zio.aws.workspaces.model.Compute] =
      scala
        .Option(impl.computeTypeName())
        .map(value => zio.aws.workspaces.model.Compute.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ): zio.aws.workspaces.model.WorkspaceProperties.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workspaces_3-5.17.295.14-sources.jar: zio/aws/workspaces/model/WorkspaceProperties.scala <==
package zio.aws.workspaces.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.workspaces.model.primitives.{
  UserVolumeSizeGib,
  RootVolumeSizeGib,
  RunningModeAutoStopTimeoutInMinutes
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class WorkspaceProperties(
    runningMode: Optional[zio.aws.workspaces.model.RunningMode] =
      Optional.Absent,
    runningModeAutoStopTimeoutInMinutes: Optional[
      RunningModeAutoStopTimeoutInMinutes
    ] = Optional.Absent,
    rootVolumeSizeGib: Optional[RootVolumeSizeGib] = Optional.Absent,
    userVolumeSizeGib: Optional[UserVolumeSizeGib] = Optional.Absent,
    computeTypeName: Optional[zio.aws.workspaces.model.Compute] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.WorkspaceProperties = {
    import WorkspaceProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
      .builder()
      .optionallyWith(runningMode.map(value => value.unwrap))(_.runningMode)
      .optionallyWith(
        runningModeAutoStopTimeoutInMinutes.map(value =>
          RunningModeAutoStopTimeoutInMinutes.unwrap(value): Integer
        )
      )(_.runningModeAutoStopTimeoutInMinutes)
      .optionallyWith(
        rootVolumeSizeGib.map(value => RootVolumeSizeGib.unwrap(value): Integer)
      )(_.rootVolumeSizeGib)
      .optionallyWith(
        userVolumeSizeGib.map(value => UserVolumeSizeGib.unwrap(value): Integer)
      )(_.userVolumeSizeGib)
      .optionallyWith(computeTypeName.map(value => value.unwrap))(
        _.computeTypeName
      )
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.WorkspaceProperties.ReadOnly =
    zio.aws.workspaces.model.WorkspaceProperties.wrap(buildAwsValue())
}
object WorkspaceProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.WorkspaceProperties =
      zio.aws.workspaces.model.WorkspaceProperties(
        runningMode.map(value => value),
        runningModeAutoStopTimeoutInMinutes.map(value => value),
        rootVolumeSizeGib.map(value => value),
        userVolumeSizeGib.map(value => value),
        computeTypeName.map(value => value)
      )
    def runningMode: Optional[zio.aws.workspaces.model.RunningMode]
    def runningModeAutoStopTimeoutInMinutes
        : Optional[RunningModeAutoStopTimeoutInMinutes]
    def rootVolumeSizeGib: Optional[RootVolumeSizeGib]
    def userVolumeSizeGib: Optional[UserVolumeSizeGib]
    def computeTypeName: Optional[zio.aws.workspaces.model.Compute]
    def getRunningMode
        : ZIO[Any, AwsError, zio.aws.workspaces.model.RunningMode] =
      AwsError.unwrapOptionField("runningMode", runningMode)
    def getRunningModeAutoStopTimeoutInMinutes
        : ZIO[Any, AwsError, RunningModeAutoStopTimeoutInMinutes] =
      AwsError.unwrapOptionField(
        "runningModeAutoStopTimeoutInMinutes",
        runningModeAutoStopTimeoutInMinutes
      )
    def getRootVolumeSizeGib: ZIO[Any, AwsError, RootVolumeSizeGib] =
      AwsError.unwrapOptionField("rootVolumeSizeGib", rootVolumeSizeGib)
    def getUserVolumeSizeGib: ZIO[Any, AwsError, UserVolumeSizeGib] =
      AwsError.unwrapOptionField("userVolumeSizeGib", userVolumeSizeGib)
    def getComputeTypeName
        : ZIO[Any, AwsError, zio.aws.workspaces.model.Compute] =
      AwsError.unwrapOptionField("computeTypeName", computeTypeName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ) extends zio.aws.workspaces.model.WorkspaceProperties.ReadOnly {
    override val runningMode: Optional[zio.aws.workspaces.model.RunningMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.runningMode())
        .map(value => zio.aws.workspaces.model.RunningMode.wrap(value))
    override val runningModeAutoStopTimeoutInMinutes
        : Optional[RunningModeAutoStopTimeoutInMinutes] = zio.aws.core.internal
      .optionalFromNullable(impl.runningModeAutoStopTimeoutInMinutes())
      .map(value =>
        zio.aws.workspaces.model.primitives
          .RunningModeAutoStopTimeoutInMinutes(value)
      )
    override val rootVolumeSizeGib: Optional[RootVolumeSizeGib] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rootVolumeSizeGib())
        .map(value =>
          zio.aws.workspaces.model.primitives.RootVolumeSizeGib(value)
        )
    override val userVolumeSizeGib: Optional[UserVolumeSizeGib] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userVolumeSizeGib())
        .map(value =>
          zio.aws.workspaces.model.primitives.UserVolumeSizeGib(value)
        )
    override val computeTypeName: Optional[zio.aws.workspaces.model.Compute] =
      zio.aws.core.internal
        .optionalFromNullable(impl.computeTypeName())
        .map(value => zio.aws.workspaces.model.Compute.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.WorkspaceProperties
  ): zio.aws.workspaces.model.WorkspaceProperties.ReadOnly = new Wrapper(impl)
}
